/*
   Copyright (c) 2001 Waldo Bastian <bastian@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

*/

#ifndef __kcmshell_h__
#define __kcmshell_h__

#include <dcopobject.h>

#include <kapplication.h>
#include <kcmultidialog.h>

class KCMShellMultiDialog : public KCMultiDialog, public DCOPObject
{
  Q_OBJECT
  K_DCOP
public:
  KCMShellMultiDialog(QWidget *parent=0, const char *name=0, bool modal=false);

k_dcop:
  virtual void activate( QCString asn_id );
};

class kcmApplication : public KApplication
{
    Q_OBJECT
public:
    bool isRunning();
    void waitForExit();  
    void setDCOPName(const QCString &dcopName);
protected slots:
    void slotAppExit(const QCString &appId);
private:
    QCString m_dcopName;
};

#endif
